@@ -9,18 +9,26 @@
 #' @param bg Default background color for the plot (defaults to "white").
 #' @param fonts Named list of font names to be aliased with
 #'   fonts installed on your system. If unspecified, the R default
-#'   families \code{sans}, \code{serif}, \code{mono} and \code{symbol}
-#'   are aliased to the family returned by \code{\link[gdtools]{match_family}()}.
+#'   families `sans`, `serif`, `mono` and `symbol` are aliased
+#'   to the families detected by [gdtools::font_set_auto()].
+#'
+#'   **Important:** fonts are referenced by name in the DrawingML output
+#'   and are **not embedded**. The reader of the Excel file must also
+#'   have the same fonts installed, otherwise Office will substitute them.
+#'   For maximum portability, prefer fonts bundled with Microsoft Office
+#'   such as `"Arial"`, `"Times New Roman"` and `"Courier New"`.
+#'
+#'   Fonts must be installed on your system; use
+#'   `gdtools::font_family_exists()` to verify availability.
+#'
+#'   Example: `list(sans = "Arial", serif = "Times New Roman", mono = "Courier New")`.
 #' @param pointsize default point size.
 #' @param editable should vector graphics elements (points, text, etc.) be editable.
-#' @param id specifies a unique identifier (integer) within the slide
-#' that will contain the DrawingML instructions.
+#' @param id specifies a unique identifier (integer) within the
+#' sheet that will contain the DrawingML instructions.
 #' @param last_rel_id specifies the last unique identifier (integer)
 #' within relationship file that will be used to reference embedded
 #' raster images if any.
-#' @param raster_prefix string value used as prefix for png
-#' files produced when raster objects are printed on the
-#' graphical device.
 #' @param standalone produce a standalone drawingml file? If \code{FALSE}, omits
 #'   xml header and namespaces.
 #' @examples
@@ -44,9 +52,12 @@ dml_xlsx <- function(
   editable = TRUE,
   id = 1L,
   last_rel_id = 1L,
-  raster_prefix = "raster_",
   standalone = TRUE
 ) {
+  img_directory <- tempfile()
+  dir.create(img_directory, recursive = TRUE, showWarnings = FALSE)
+  raster_prefix <- paste0(img_directory, "/raster-")
+
   system_fonts <- validate_fonts(fonts)
   invisible(XLSX_(
     file,
